---
title: '[릴리즈노트] 2024-06-03  업데이트'
category: 업데이트
tags:
  - API / SDK
  - 업데이트
searchTags:
  - 스마트 라우팅
  - 업데이트
  - 릴리즈노트
datetime: 2024-06-02T15:00:00.000Z
---

<Callout title="2024년 6월 3일 API / SDK 업데이트 소식을 안내드립니다." />



## 주요 업데이트 사항

<Tag text="결제 서비스 V2" />

✔️ **스**마트 라우팅 기능이 새롭게 출시되었습니다.

포트원 V2에서 스마트 라우팅 기능을 제공합니다.



### 스마트 라우팅이란?

스마트 라우팅은 원클릭 결제 트래픽 자동 분산 서비스로 최초 연동 이후 포트원 관리자콘솔 내에서 결제대행사 추가/삭제 및 결제대행사 별 결제 요청 비율을 설정할 수 있습니다. 노코드 방식으로 고객사에서 멀티 PG 인프라를 구성하는데 필요한 개발 리소스를 확 줄였습니다.

지원 범위

- 결제창(SDK) 인증결제
- API 수기(키인) 결제
- API 빌링키 발급 및 빌링키결제/예약결제

지원 기능

1. 스마트 라우팅 그룹 설정에 따른 결제 트래픽 분산 자동화
2. 슈퍼빌링키 발급

- 스마트 라우팅 그룹 내 모든 결제대행사에 대해 빌링키 발급 요청 및 저장

지원 결제대행사

- 나이스페이먼츠
- KG이니시스
- 토스페이먼츠
- 스마트로
- KSNET
- KPN
- NHN KCP (6월 중 제공 예정)

이번 업데이트를 통해 스마트 라우팅 그룹을 생성하고 자동화된 결제 트래픽 분산 서비스를 경험해보세요

스마트 라우팅에 대해 자세히 알고 싶다면[→ 스마트 라우팅 소개(클릭)](https://developers.portone.io/opi/ko/extra/smart-routing/intro?v=v2) 문서에서 확인하실 수 있습니다.

#### [\[API/SDK 릴리즈노트\] 2024-06-03 업데이트 보러가기↗](https://developers.portone.io/release-notes/api-sdk/2024-06-03)
